
# Type: uri

a complete URI

URI: [linkml:Uri](https://w3id.org/linkml/Uri)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **URI** |
| Representation | | str |

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | in RDF serializations a slot with range of uri is treated as a literal or type xsd:anyURI unless it is an identifier or a reference to an identifier, in which case it is translated directly to a node |
| **Close Mappings:** | | schema:URL |
